/******************************************************************************
* File Name:   main.c
*
* Description: This is the source code for the PSoC 6 MCU Hello World Example
*              for ModusToolbox.
*
* Related Document: See Readme.md
*
*******************************************************************************
* (c) 2019, Cypress Semiconductor Corporation. All rights reserved.
*******************************************************************************
* This software, including source code, documentation and related materials
* ("Software"), is owned by Cypress Semiconductor Corporation or one of its
* subsidiaries ("Cypress") and is protected by and subject to worldwide patent
* protection (United States and foreign), United States copyright laws and
* international treaty provisions. Therefore, you may use this Software only
* as provided in the license agreement accompanying the software package from
* which you obtained this Software ("EULA").
*
* If no EULA applies, Cypress hereby grants you a personal, non-exclusive,
* non-transferable license to copy, modify, and compile the Software source
* code solely for use in connection with Cypress's integrated circuit products.
* Any reproduction, modification, translation, compilation, or representation
* of this Software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: THIS SOFTWARE IS PROVIDED AS-IS, WITH NO WARRANTY OF ANY KIND,
* EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Cypress
* reserves the right to make changes to the Software without notice. Cypress
* does not assume any liability arising out of the application or use of the
* Software or any product or circuit described in the Software. Cypress does
* not authorize its products for use in any products where a malfunction or
* failure of the Cypress product may reasonably be expected to result in
* significant property damage, injury or death ("High Risk Product"). By
* including Cypress's product in a High Risk Product, the manufacturer of such
* system or application assumes all risk of such use and in doing so agrees to
* indemnify Cypress against all liability.
*******************************************************************************/

#include "project.h"
//#include "cy_pdl.h"
//#include "cyhal.h"
//#include "cybsp.h"
//#include "cy_retarget_io.h"


/*******************************************************************************
* Macros
*******************************************************************************/

#define SYSTICK_MAX_CNT_BITS 16u
#define SYSTICK_MAX_CNT		(1<<SYSTICK_MAX_CNT_BITS)-1

/*******************************************************************************
* Function Prototypes
*******************************************************************************/


uint32_t tick = 0;
uint32_t systick_wrap = 0;
uint32_t getcount_flag = 0;
/*********************************************************************************/
void systick_isr(void)
{
	systick_wrap++;
}

/*******************************************************************************
* Function Name: main
********************************************************************************
* Summary:
* This is the main function for CM4 CPU. It sets up a timer to trigger a 
* periodic interrupt. The main while loop checks for the status of a flag set 
* by the interrupt and toggles an LED at 1Hz to create an LED blinky. The 
* while loop also checks whether the 'Enter' key was pressed and 
* stops/restarts LED blinking.
*
* Parameters:
*  none
*
* Return:
*  int
*
*******************************************************************************/
int main(void)
{

    /* Enable global interrupts */
    __enable_irq();

    UART_Start();

/*Initialize and Enable the SysTick resource*/
	Cy_SysTick_Init(CY_SYSTICK_CLOCK_SOURCE_CLK_LF, SYSTICK_MAX_CNT);	// Reload counter is set to maximum of the 24-bit counter
	Cy_SysTick_SetCallback(0, systick_isr);		// point to SysTick ISR to increment the 1ms count

    UART_PutString("****************** "
           "Cy_SysTick_GetCountFlag() Issue test "
           "****************** \r\n\n");

    for(;;)
    {
    	static uint32_t systick_wrap_prev = 0;
    	static uint32_t getcount_flag_prev = 0;

    	if(systick_wrap_prev != systick_wrap)
    	{	// systick_wrap was incremented.
        	UART_PutString("SysTick counter wrapped!\r\n");
        	systick_wrap_prev = systick_wrap;
    	}
    	if(getcount_flag_prev != getcount_flag)
    	{	// systick_wrap was incremented.
        	UART_PutString("GetCount_Flag received!\r\n");
        	getcount_flag_prev = getcount_flag;
    	}
        if(Cy_SysTick_GetCountFlag() != 0u)
        {
        	getcount_flag++;    	// Inc systick_wrap every time the SysTick counter decs to 0.
        }
     }
}


/* [] END OF FILE */

